/*
 !!!!!!!   DO NOT EDIT THIS FILE   !!!!!!!
 This file was autogenerated by:
 /home/sand/src/perl/repoperls/installed-perls/perl/v5.23.6/de40/bin/perl /home/sand/src/perl/repoperls/installed-perls/perl/v5.23.6/de40/bin/enc2xs -Q -o MAB2table_t.c -f MAB2table_t.fnm
 enc2xs VERSION 2.18
*/
extern encode_t MAB2table_encoding;
